pub enum DeclKind {
Object,
Function,
}Expand description
Whether a declaration declares an object or a function.
A typedef and an enumerator are neither: one is a name for a type and the other is a
constant, and both have been resolved by the time anything reads this.
Variants
Object
An object, which includes parameters, block-scope variables and compound literals.
Function
A function.