pub struct Asm {
pub template: StrId,
pub outputs: AsmOperandList,
pub inputs: AsmOperandList,
pub clobbers: StrList,
pub labels: LabelList,
pub quals: AsmQuals,
}Expand description
One asm statement.
Fields
template: StrIdThe template, which is passed to the assembler with the operands substituted into it.
outputs: AsmOperandListThe output operands, which are numbered from zero.
inputs: AsmOperandListThe input operands, which are numbered after the outputs.
clobbers: StrListThe clobber list.
labels: LabelListThe labels of an asm goto, empty for everything else.
quals: AsmQualsThe qualifiers, with volatile set for a statement that implies it.