Tag

Struct Tag 

pub struct Tag {
    pub kind: TagKind,
    pub ty: TypeId,
}
A tag, and the type it names.

Fields

kind: TagKind

Which keyword declared it.

ty: TypeId

The type, which exists from the point the tag is first mentioned and is incomplete until the definition is read.