pub enum Sign {
Clear,
Of,
}Expand description
Where the sign of the answer to one of the sign builtins comes from.
Neither of these is a computation on the value. fabs of a NaN is that NaN with its sign bit
clear, payload and all, and copysign of one is that NaN with the other value’s sign bit, so
what both do is described entirely in terms of the bits.
Variants
Clear
fabs(x), whose sign is always clear.
Of
copysign(x, y), whose sign is the sign of the second operand.
Implementations