pub struct Tag {
pub kind: TagKind,
pub ty: TypeId,
}Expand description
A tag, and the type it names.
Fields
kind: TagKindWhich keyword declared it.
ty: TypeIdThe type, which exists from the point the tag is first mentioned and is incomplete until the definition is read.